@@ -83,6 +83,7 @@ OC.L10N.register(
     "Days after which messages in Trash will automatically be deleted:" : "Days after which messages in Trash will automatically be deleted:",
     "Autoresponder" : "Autoresponder",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days.",
+    "Calendar settings" : "Calendar settings",
     "Mail server" : "Mail server",
     "Update alias" : "Update alias",
     "Rename alias" : "Rename alias",
@@ -94,34 +95,21 @@ OC.L10N.register(
     "Add alias" : "Add alias",
     "Create alias" : "Create alias",
     "Cancel" : "Cancel",
-    "Search in the body of messages in priority Inbox" : "Search in the body of messages in priority Inbox",
     "Activate" : "Activate",
-    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it.",
     "Could not update preference" : "Could not update preference",
     "Mail settings" : "Mail settings",
-    "Accounts" : "Accounts",
-    "Add mail account" : "Add mail account",
     "General" : "General",
+    "Add mail account" : "Add mail account",
     "List" : "List",
     "Sorting" : "Sorting",
-    "Newest" : "Newest",
-    "Oldest" : "Oldest",
-    "Reply text position" : "Reply text position",
-    "Gravatar settings" : "Gravatar settings",
-    "Use Gravatar and favicon avatars" : "Use Gravatar and favicon avatars",
-    "Mailto" : "Mailto",
-    "Register as application for mail links" : "Register as application for mail links",
-    "Register" : "Register",
+    "Newest first" : "Newest first",
+    "Oldest first" : "Oldest first",
     "Shared with me" : "Shared with me",
-    "Data collection consent" : "Data collection consent",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
-    "Trusted senders" : "Trusted senders",
+    "Privacy" : "Privacy",
+    "Security" : "Security",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "Manage S/MIME certificates",
     "Mailvelope" : "Mailvelope",
-    "Looking for a way to encrypt your emails?" : "Looking for a way to encrypt your emails?",
     "About" : "About",
-    "Keyboard shortcuts" : "Keyboard shortcuts",
     "Compose new message" : "Compose new message",
     "Newer message" : "Newer message",
     "Older message" : "Older message",
@@ -153,16 +141,12 @@ OC.L10N.register(
     "From" : "From",
     "Select account" : "Select account",
     "To" : "To",
-    "Contact or email address …" : "Contact or email address …",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Subject",
-    "Subject …" : "Subject …",
     "This message came from a noreply address so your reply will probably not be read." : "This message came from a noreply address so your reply will probably not be read.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "The following recipients do not have a S/MIME certificate: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "The following recipients do not have a PGP key: {recipients}.",
-    "Write message …" : "Write message …",
-    "Saving draft …" : "Saving draft …",
     "Error saving draft" : "Error saving draft",
     "Draft saved" : "Draft saved",
     "Save draft" : "Save draft",
@@ -234,7 +218,6 @@ OC.L10N.register(
     "Back" : "Back",
     "Set custom snooze" : "Set custom snooze",
     "Edit as new message" : "Edit as new message",
-    "Create event" : "Create event",
     "Create task" : "Create task",
     "Download message" : "Download message",
     "Load more" : "Load more",
@@ -250,10 +233,14 @@ OC.L10N.register(
     "_Edit tags for {number}_::_Edit tags for {number}_" : ["Edit tags for {number}","Edit tags for {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Move {number} thread","Move {number} threads"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Forward {number} as attachment","Forward {number} as attachment"],
+    "Mark as unread" : "Mark as unread",
+    "Mark as read" : "Mark as read",
     "Report this bug" : "Report this bug",
     "Event created" : "Event created",
     "Could not create event" : "Could not create event",
+    "Create event" : "Create event",
     "All day" : "All day",
+    "Attendees" : "Attendees",
     "Select calendar" : "Select calendar",
     "Description" : "Description",
     "Create" : "Create",
@@ -279,17 +266,16 @@ OC.L10N.register(
     "individual" : "individual",
     "domain" : "domain",
     "Remove" : "Remove",
-    "email" : "email",
     "Itinerary for {type} is not supported yet" : "Itinerary for {type} is not supported yet",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
     "Today" : "დღეს",
     "Yesterday" : "გუშინ",
     "Last week" : "Last week",
     "Last month" : "Last month",
-    "Loading messages …" : "Loading messages …",
     "Choose target folder" : "Choose target folder",
     "No more submailboxes in here" : "No more submailboxes in here",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
+    "Favorites" : "Favorites",
     "Important info" : "Important info",
     "Other" : "Other",
     "Could not send mdn" : "Could not send mdn",
@@ -343,7 +329,6 @@ OC.L10N.register(
     "Move down" : "Move down",
     "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
-    "Loading …" : "Loading …",
     "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
     "Clear mailbox {name}" : "Clear mailbox {name}",
     "Delete folder" : "Delete folder",
@@ -394,7 +379,6 @@ OC.L10N.register(
     "Add to Contact" : "Add to Contact",
     "New Contact" : "New Contact",
     "Copy to clipboard" : "Copy to clipboard",
-    "Contact name …" : "Contact name …",
     "Add" : "Add",
     "Show less" : "Show less",
     "Show more" : "Show more",
@@ -415,7 +399,6 @@ OC.L10N.register(
     "Select tags" : "Select tags",
     "Marked as" : "Marked as",
     "Has attachments" : "Has attachments",
-    "Last 7 days" : "Last 7 days",
     "Enable mail body search" : "Enable mail body search",
     "Sieve Port" : "Sieve Port",
     "Custom" : "Custom",
@@ -424,14 +407,12 @@ OC.L10N.register(
     "Save sieve settings" : "Save sieve settings",
     "The syntax seems to be incorrect:" : "The syntax seems to be incorrect:",
     "Save sieve script" : "Save sieve script",
-    "Signature …" : "Signature …",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Your signature is larger than 2 MB. This may affect the performance of your editor.",
     "Save signature" : "Save signature",
     "Place signature above quoted text" : "Place signature above quoted text",
     "Message source" : "Message source",
     "An error occurred, unable to rename the tag." : "An error occurred, unable to rename the tag.",
     "Edit name or color" : "Edit name or color",
-    "Saving new tag name …" : "Saving new tag name …",
     "Delete tag" : "Delete tag",
     "Set tag" : "Set tag",
     "Unset tag" : "Unset tag",
@@ -441,7 +422,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "An error occurred, unable to create the tag.",
     "Add default tags" : "Add default tags",
     "Add tag" : "Add tag",
-    "Saving tag …" : "Saving tag …",
     "Task created" : "Task created",
     "Could not create task" : "Could not create task",
     "No calendars with task list support" : "No calendars with task list support",
@@ -463,15 +443,12 @@ OC.L10N.register(
     "Reply to sender only" : "Reply to sender only",
     "Mark as unfavorite" : "Mark as unfavorite",
     "Mark as favorite" : "Mark as favorite",
-    "Mark as unread" : "Mark as unread",
-    "Mark as read" : "Mark as read",
     "Unsubscribe via link" : "Unsubscribe via link",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Unsubscribing will stop all messages from the mailing list {sender}",
     "Send unsubscribe email" : "Send unsubscribe email",
     "Unsubscribe via email" : "Unsubscribe via email",
     "{name} Assistant" : "{name} Assistant",
     "Go to latest message" : "Go to latest message",
-    "Go to newest message" : "Go to newest message",
     "The message could not be translated" : "The message could not be translated",
     "Translation copied to clipboard" : "Translation copied to clipboard",
     "Translation could not be copied" : "Translation could not be copied",
@@ -495,9 +472,12 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} from {depStation} to {arrStation}",
     "Train from {depStation} to {arrStation}" : "Train from {depStation} to {arrStation}",
     "Train" : "Train",
-    "Operator" : "ოპერატორი",
+    "Deleted" : "Deleted",
+    "Help" : "Help",
     "matches" : "matches",
+    "Actions" : "Actions",
     "Priority" : "Priority",
+    "Edit" : "Edit",
     "Successfully updated config for \"{domain}\"" : "Successfully updated config for \"{domain}\"",
     "Error saving config" : "Error saving config",
     "Saved config for \"{domain}\"" : "Saved config for \"{domain}\"",
@@ -608,7 +588,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "To add a mail account, please contact your administrator.",
     "All" : "All",
     "Drafts" : "Drafts",
-    "Favorites" : "Favorites",
     "Priority inbox" : "Priority inbox",
     "All inboxes" : "All inboxes",
     "Inbox" : "Inbox",
@@ -640,30 +619,6 @@ OC.L10N.register(
     "The link leads to %s" : "The link leads to %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "Continue to %s",
-    "Mailbox search" : "Mailbox search",
-    "Install Mailvelope browser extension by clicking here" : "Install Mailvelope browser extension by clicking here",
-    "No messages in this mailbox" : "No messages in this mailbox",
-    "No trash mailbox configured" : "No trash mailbox configured",
-    "Draft: " : "Draft: ",
-    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
-    "Could not open mailbox" : "Could not open mailbox",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexing your messages. This can take a bit longer for larger mailboxes.",
-    "Choose target mailbox" : "Choose target mailbox",
-    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
-    "Add mailbox" : "Add mailbox",
-    "Mailbox name" : "Mailbox name",
-    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
-    "Show all mailboxes" : "Show all mailboxes",
-    "Collapse mailboxes" : "Collapse mailboxes",
-    "Clear mailbox" : "Clear mailbox",
-    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
-    "Delete mailbox" : "Delete mailbox",
-    "Delete mailbox {name}" : "Delete mailbox {name}",
-    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
-    "Add submailbox" : "Add submailbox",
-    "Move mailbox" : "Move mailbox",
-    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
-    "Search in mailbox" : "Search in mailbox",
-    "Actions" : "Actions"
+    "Last 7 days" : "Last 7 days"
 },
 "nplurals=2; plural=(n!=1);");
